==> aws_prototyping_sdk.open_api_gateway-0.7.1.tar.gz: package/lib/construct/open-api-gateway-lambda-api.d.ts <==
/*********************************************************************************************************************
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

 Licensed under the Apache License, Version 2.0 (the "License").
 You may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 ******************************************************************************************************************** */
import { RestApiBaseProps, SpecRestApi } from "aws-cdk-lib/aws-apigateway";
import { Construct } from "constructs";
import { OpenApiOptions } from "./spec";
/**
 * Configuration for the OpenApiGatewayLambdaApi construct
 */
export interface OpenApiGatewayLambdaApiProps extends RestApiBaseProps, OpenApiOptions {
    /**
     * The parsed OpenAPI specification
     */
    readonly spec: any;
    /**
     * Path to the JSON open api spec
     */
    readonly specPath: string;
}
/**
 * A construct for creating an api gateway api based on the definition in the OpenAPI spec.
 */
export declare class OpenApiGatewayLambdaApi extends Construct {
    readonly api: SpecRestApi;
    constructor(scope: Construct, id: string, props: OpenApiGatewayLambdaApiProps);
}

==> aws_prototyping_sdk.open_api_gateway-0.10.3.tar.gz: package/lib/construct/open-api-gateway-lambda-api.d.ts <==
/*********************************************************************************************************************
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

 Licensed under the Apache License, Version 2.0 (the "License").
 You may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 ******************************************************************************************************************** */
import { RestApiBaseProps, SpecRestApi } from "aws-cdk-lib/aws-apigateway";
import { CfnIPSet, CfnWebACL, CfnWebACLAssociation } from "aws-cdk-lib/aws-wafv2";
import { Construct } from "constructs";
import { OpenApiOptions } from "./spec";
import { OpenApiGatewayWebAclOptions } from "./waf/types";
/**
 * Configuration for the OpenApiGatewayLambdaApi construct
 */
export interface OpenApiGatewayLambdaApiProps extends RestApiBaseProps, OpenApiOptions {
    /**
     * The parsed OpenAPI specification
     */
    readonly spec: any;
    /**
     * Path to the JSON open api spec
     */
    readonly specPath: string;
    /**
     * Options for the AWS WAF v2 WebACL associated with the api. By default, a Web ACL with the AWS default managed
     * rule set will be associated with the API. These options may disable or override the defaults.
     */
    readonly webAclOptions?: OpenApiGatewayWebAclOptions;
}
/**
 * A construct for creating an api gateway api based on the definition in the OpenAPI spec.
 */
export declare class OpenApiGatewayLambdaApi extends Construct {
    readonly api: SpecRestApi;
    readonly webAcl?: CfnWebACL;
    readonly ipSet?: CfnIPSet;
    readonly webAclAssociation?: CfnWebACLAssociation;
    constructor(scope: Construct, id: string, props: OpenApiGatewayLambdaApiProps);
}
